wagoe.ai.schema

Malli validation schemas for the AI module.

Malli validation schemas for the AI module.
raw docstring

AIConfigclj

Top-level AI module configuration.

Top-level AI module configuration.
sourceraw docstring

AIRequestclj

Input to an AI completion call.

Input to an AI completion call.
sourceraw docstring

AIResponseclj

Output from an AI completion call.

Output from an AI completion call.
sourceraw docstring

Messageclj

A single message in an AI conversation. :role — :system, :user, or :assistant :content — the message text

A single message in an AI conversation.
:role    — :system, :user, or :assistant
:content — the message text
sourceraw docstring

ProviderConfigclj

Configuration for a single AI provider.

Configuration for a single AI provider.
sourceraw docstring

valid-ai-response?clj

(valid-ai-response? resp)

Returns true if the given map satisfies the AIResponse schema.

Returns true if the given map satisfies the AIResponse schema.
sourceraw docstring

valid-message?clj

(valid-message? msg)

Returns true if the given map satisfies the Message schema.

Returns true if the given map satisfies the Message schema.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries