Malli validation schemas for the AI module.
Malli validation schemas for the AI module.
Top-level AI module configuration.
Top-level AI module configuration.
Output from an AI completion call.
Output from an AI completion call.
A single message in an AI conversation. :role — :system, :user, or :assistant :content — the message text
A single message in an AI conversation. :role — :system, :user, or :assistant :content — the message text
Configuration for a single AI provider.
Configuration for a single AI provider.
(valid-ai-response? resp)Returns true if the given map satisfies the AIResponse schema.
Returns true if the given map satisfies the AIResponse schema.
(valid-message? msg)Returns true if the given map satisfies the Message schema.
Returns true if the given map satisfies the Message schema.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |